==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/RouteDestinationFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RouteDestinationFluent<A extends RouteDestinationFluent<A>> extends BaseFluent<A>{
  public RouteDestinationFluent() {
  }
  public RouteDestinationFluent(RouteDestination instance) {
    instance = (instance != null ? instance : new RouteDestination());

    if (instance != null) {
      this.withDestination(instance.getDestination());
      this.withWeight(instance.getWeight());
      this.withDestination(instance.getDestination());
      this.withWeight(instance.getWeight());
    }
  }
  private DestinationBuilder destination;
  private Integer weight;
  public Destination buildDestination() {
    return this.destination!=null ?this.destination.build():null;
  }
  public A withDestination(Destination destination) {
    _visitables.get("destination").remove(this.destination);
    if (destination!=null){ this.destination= new DestinationBuilder(destination); _visitables.get("destination").add(this.destination);} else { this.destination = null; _visitables.get("destination").remove(this.destination); } return (A) this;
  }
  public boolean hasDestination() {
    return this.destination != null;
  }
  public DestinationNested<A> withNewDestination() {
    return new DestinationNested(null);
  }
  public DestinationNested<A> withNewDestinationLike(Destination item) {
    return new DestinationNested(item);
  }
  public DestinationNested<A> editDestination() {
    return withNewDestinationLike(java.util.Optional.ofNullable(buildDestination()).orElse(null));
  }
  public DestinationNested<A> editOrNewDestination() {
    return withNewDestinationLike(java.util.Optional.ofNullable(buildDestination()).orElse(new DestinationBuilder().build()));
  }
  public DestinationNested<A> editOrNewDestinationLike(Destination item) {
    return withNewDestinationLike(java.util.Optional.ofNullable(buildDestination()).orElse(item));
  }
  public Integer getWeight() {
    return this.weight;
  }
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  public boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteDestinationFluent that = (RouteDestinationFluent) o;
    if (!java.util.Objects.equals(destination, that.destination)) return false;

    if (!java.util.Objects.equals(weight, that.weight)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destination,  weight,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  public class DestinationNested<N> extends DestinationFluent<DestinationNested<N>> implements Nested<N>{
    DestinationNested(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) RouteDestinationFluent.this.withDestination(builder.build());
    }
    public N endDestination() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/RouteDestinationFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RouteDestinationFluent<A extends RouteDestinationFluent<A>> extends BaseFluent<A>{
  public RouteDestinationFluent() {
  }
  
  public RouteDestinationFluent(RouteDestination instance) {
    this.copyInstance(instance);
  }
  private DestinationBuilder destination;
  private Integer weight;
  
  protected void copyInstance(RouteDestination instance) {
    instance = (instance != null ? instance : new RouteDestination());
  
    if (instance != null) {
        this.withDestination(instance.getDestination());
        this.withWeight(instance.getWeight());
        this.withDestination(instance.getDestination());
        this.withWeight(instance.getWeight());
      }
  }
  
  public Destination buildDestination() {
    return this.destination!=null ?this.destination.build():null;
  }
  
  public A withDestination(Destination destination) {
    _visitables.get("destination").remove(this.destination);
    if (destination!=null){ this.destination= new DestinationBuilder(destination); _visitables.get("destination").add(this.destination);} else { this.destination = null; _visitables.get("destination").remove(this.destination); } return (A) this;
  }
  
  public boolean hasDestination() {
    return this.destination != null;
  }
  
  public DestinationNested<A> withNewDestination() {
    return new DestinationNested(null);
  }
  
  public DestinationNested<A> withNewDestinationLike(Destination item) {
    return new DestinationNested(item);
  }
  
  public DestinationNested<A> editDestination() {
    return withNewDestinationLike(java.util.Optional.ofNullable(buildDestination()).orElse(null));
  }
  
  public DestinationNested<A> editOrNewDestination() {
    return withNewDestinationLike(java.util.Optional.ofNullable(buildDestination()).orElse(new DestinationBuilder().build()));
  }
  
  public DestinationNested<A> editOrNewDestinationLike(Destination item) {
    return withNewDestinationLike(java.util.Optional.ofNullable(buildDestination()).orElse(item));
  }
  
  public Integer getWeight() {
    return this.weight;
  }
  
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  
  public boolean hasWeight() {
    return this.weight != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteDestinationFluent that = (RouteDestinationFluent) o;
    if (!java.util.Objects.equals(destination, that.destination)) return false;
  
    if (!java.util.Objects.equals(weight, that.weight)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destination,  weight,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  public class DestinationNested<N> extends DestinationFluent<DestinationNested<N>> implements Nested<N>{
    DestinationNested(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DestinationBuilder builder;
    
    public N and() {
      return (N) RouteDestinationFluent.this.withDestination(builder.build());
    }
    
    public N endDestination() {
      return and();
    }
    
  
  }

}
